@@ -1,10 +1,18 @@
+use caprice::theme::{Theme, DEFAULT_THEME};
 use caprice::{Caprice, CapriceCommand};
+use crossterm::style::Color;
 use std::thread;
 use std::time::Duration;
+
 fn main() {
     let caprice = Caprice::new()
         .set_prompt("!:") // set the prompt
         .disable_ctrl_c() // pressing control + c won't terminate the caprice console
+        .theme(Theme {
+            // Set Caprice options
+            prompt_color: Color::Yellow,
+            ..DEFAULT_THEME
+        })
         .set_keywords(vec![
             // set some tokens
             "some_token".to_owned(),
